Summary level configuration for code analysis
This module defines the different levels of summary extraction that batless can perform.
Enums
- Summary
Level - Summary extraction level for code analysis
Summary level configuration for code analysis
This module defines the different levels of summary extraction that batless can perform.